@@ -16,10 +16,9 @@
   02110-1301, USA.
 */
 #include <config.h>
-#include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
-#include "xvasprintf.h"
+#include "reddit_priv.h"
 #include "downvote.h"
 #include "upvote.h"
 #include "gettext-more.h"
@@ -27,11 +26,6 @@
 #include "stories.h"
 
 
-static struct argp_option options[] = 
-{
-    {0}
-};
-
 static error_t 
 parse_opt (int key, char *arg, struct argp_state *state)
 {
@@ -81,7 +75,7 @@ help_filter (int key, const char *text, void *in)
   return argp_parse_story_help_filter (key, text, o ? o->state : NULL);
 }
 
-struct argp reddit_downvote_argp = { options, parse_opt, "STORY-NUMBER",N_("Decreases the number of people who liked a given story.  Tallies your vote against the story."), 0, help_filter };
+struct argp reddit_downvote_argp = { NULL, parse_opt, "STORY-NUMBER",N_("Decreases the number of people who liked a given story.  Tallies your vote against the story."), 0, help_filter };
 
 int 
 reddit_downvote_parse_argp (struct reddit_state_t *state, int argc, char **argv, struct argp *argp)
@@ -107,8 +101,8 @@ reddit_downvote (struct reddit_state_t *state, struct reddit_downvote_options_t
   int err = 0;
   if (state->logged_in == 0)
     {
-      fprintf (state->out, _("You need to login to vote on a story."
-                             "  Login using the `login' command.\n"));
+      reddintf (state, _("You need to login to vote on a story."
+                         "  Login using the `login' command.\n"));
       return 0;
     }
   struct reddit_story_t *story = 
@@ -121,16 +115,16 @@ reddit_downvote (struct reddit_state_t *state, struct reddit_downvote_options_t
   if (!err)
     reddit_update_modhash (state);
   if (!err)
-    fprintf (state->out, _("The story has been downvoted.\n"));
+    reddintf (state, _("The story has been downvoted.\n"));
   else
     {
-      fprintf (state->out, _("Error: Couldn't downvote the story "
+      reddintf (state, _("Error: Couldn't downvote the story "
                              "HTTP /1.1 %d err=%d)\n"), response, err);
       if (errmsg)
         {
-          fprintf (state->out, _("Maybe this gobbledegook will be useful "
-                                 "in diagnosing what went wrong:\n"
-                                 "%s\n"), errmsg);
+          reddintf (state, _("Maybe this gobbledegook will be useful "
+                             "in diagnosing what went wrong:\n"
+                             "%s\n"), errmsg);
           free (errmsg);
         }
     }
