@@ -16,18 +16,12 @@
   02110-1301, USA.
 */
 #include <config.h>
-#include <stdio.h>
 #include <stdlib.h>
-#include "xvasprintf.h"
+#include "reddit_priv.h"
 #include "gosub.h"
 #include "story.h"
 #include "gettext-more.h"
 
-static struct argp_option options[] = 
-{
-    {0}
-};
-
 static error_t 
 parse_opt (int key, char *arg, struct argp_state *state)
 {
@@ -49,15 +43,6 @@ parse_opt (int key, char *arg, struct argp_state *state)
             }
         }
       break;
-    case ARGP_KEY_NO_ARGS:
-      if (state->next <= 1)
-        {
-          argp_failure (state, 0, 0, 
-                        _("You must specify a subreddit to go to."));
-          argp_state_help (state, state->err_stream, ARGP_HELP_SEE);
-          opt->parsing_errors = 1;
-        }
-      break;
     case ARGP_KEY_INIT:
       opt->subreddit = NULL;
       opt->parsing_errors = 0;
@@ -68,7 +53,9 @@ parse_opt (int key, char *arg, struct argp_state *state)
   return 0;
 }
 
-struct argp reddit_gosub_argp = { options, parse_opt, "SUBREDDIT-NAME",N_("Go to a subreddit.\v") };
+struct argp reddit_gosub_argp = { NULL, parse_opt, "[SUBREDDIT-NAME]",
+  N_("Go to a subreddit.\v"
+     "When the SUBREDDIT-NAME is omitted, a list of reddits is displayed.") };
 
 int 
 reddit_gosub_parse_argp (struct reddit_state_t *state, int argc, char **argv, struct argp *argp)
@@ -78,7 +65,7 @@ reddit_gosub_parse_argp (struct reddit_state_t *state, int argc, char **argv, st
   gosub_options.state = state;
 
   err = argp_parse (argp, argc, argv, ARGP_NO_EXIT,  0, &gosub_options);
-  if (!err && gosub_options.subreddit != NULL && !gosub_options.parsing_errors)
+  if (!err && !gosub_options.parsing_errors)
     return reddit_gosub (state, &gosub_options);
   else
     return 0;
@@ -99,12 +86,23 @@ reddit_gosub (struct reddit_state_t *state, struct reddit_gosub_options_t *optio
 {
   int err = 0;
   int response = 0;
+  if (options->subreddit == NULL)
+    {
+      char *prev = NULL;
+      char *reddit;
+      while ((reddit = argz_next(state->reddits, state->reddits_len, prev)))
+        {
+          prev = reddit;
+          reddintf (state, "%s\n", reddit);
+        }
+      return err;
+    }
   err = reddit_load_and_show_stories (state, "", 0, options->subreddit, &response);
   if (err)
     {
-      fprintf (state->out, _("Error: Couldn't load page for subreddit `%s'.  "
-                             "(HTTP /1.1 %d err=%d)\n"), options->subreddit,
-                             response, err);
+      reddintf (state, _("Error: Couldn't load page for subreddit `%s'.  "
+                         "(HTTP /1.1 %d err=%d)\n"), options->subreddit,
+                response, err);
       err = 0;
     }
   return err;
