@@ -16,21 +16,22 @@
   02110-1301, USA.
 */
 #include <config.h>
-#include <stdio.h>
 #include <stdlib.h>
 #include <curl/curl.h>
 #include <unistd.h>
 #include "xvasprintf.h"
+#include "gettext-more.h"
+#include "getpass.h"
+#include "reddit_priv.h"
 #include "login.h"
 #include "story.h"
 #include "stories.h"
-#include "gettext-more.h"
-#include "getpass.h"
-#include "xvasprintf.h"
+#include "wallet.h"
 
 static struct argp_option options[] = 
 {
     {"password", 'p', "PASSWORD", OPTION_HIDDEN, N_("specify a password.")},
+    {"no-wallet", 'n', 0, 0, N_("don't use passwords from the wallet")},
     {0}
 };
 
@@ -42,6 +43,9 @@ parse_opt (int key, char *arg, struct argp_state *state)
     opt = (struct reddit_login_options_t*) state->input;
   switch (key)
     {
+    case 'n':
+      opt->no_wallet = 1;
+      break;
     case 'p':
       opt->password = arg;
       break;
@@ -70,6 +74,7 @@ parse_opt (int key, char *arg, struct argp_state *state)
     case ARGP_KEY_INIT:
       opt->username = NULL;
       opt->password = NULL;
+      opt->no_wallet = 0;
       opt->parsing_errors = 0;
       break;
     default:
@@ -78,7 +83,7 @@ parse_opt (int key, char *arg, struct argp_state *state)
   return 0;
 }
 
-struct argp reddit_login_argp = { options, parse_opt, "USERNAME",N_("Login to reddit.com.") };
+struct argp reddit_login_argp = { options, parse_opt, "USERNAME",N_("Login to " REDDIT_SITE ".") };
 
 int 
 reddit_login_parse_argp (struct reddit_state_t *state, int argc, char **argv, struct argp *argp)
@@ -128,48 +133,65 @@ reddit_login_with_credentials (struct reddit_state_t *state, struct reddit_login
   return err;
 }
 
-
 int 
 reddit_login (struct reddit_state_t *state, struct reddit_login_options_t *options)
 {
+  int free_pass = 0;
   int err = 0;
   char *p = NULL;
   if (state->logged_in && strcmp (state->username, options->username) == 0)
     {
-      fprintf (state->out, _("You are already logged in.\n"));
+      reddintf (state, _("You are already logged in.\n"));
       return 0;
     }
 
-  fflush (stdout);
-  if (options->password == NULL)
+  if (state->wallet && options->password == NULL && options->no_wallet == 0)
+    {
+      p = get_password_from_wallet (state->wallet, REDDIT_WALLET_PASS, 
+                                    options->username, state->site,
+                                    state->openssl_binary);
+      if (p)
+        free_pass = 1;
+    }
+  if (!p)
     p = getpass (_("Password: "));
 
-  options->password = p;
+  if (options->password == NULL)
+    options->password = p;
 
   int response = 0;
   char *errmsg = NULL;
   err = reddit_login_with_credentials (state, options, &response, &errmsg);
 
-  memset (options->password, 0, strlen (options->password));
   if (!err)
     {
       free (state->username);
       state->username = strdup (options->username);
       state->logged_in = 1;
+      if (state->wallet)
+        {
+          if (add_to_wallet (state->wallet, REDDIT_WALLET_PASS, 
+                             options->username, state->site, options->password,
+                             state->openssl_binary))
+            reddintf (state, _("Saved password to wallet.\n"));
+        }
       reddit_update_modhash (state);
-      fprintf (state->out, _("Hello redditor.\n"));
+      reddintf (state, _("Hello redditor.\n"));
     }
   else
     {
-      fprintf (state->out, _("Error: Login unsuccessful.  " 
-                             "(HTTP /1.1 %d err=%d\n"), response, err);
+      reddintf (state, _("Error: Login unsuccessful.  " 
+                         "(HTTP /1.1 %d err=%d)\n"), response, err);
       if (errmsg)
         {
-          fprintf (state->out, _("Maybe this gobbledegook will be useful "
-                                 "in diagnosing what went wrong:\n"
-                                 "%s\n"), errmsg);
+          reddintf (state, _("Maybe this gobbledegook will be useful "
+                             "in diagnosing what went wrong:\n"
+                             "%s\n"), errmsg);
           free (errmsg);
         }
     }
+  memset (options->password, 0, strlen (options->password));
+  if (free_pass)
+    free (p);
   return err;
 }
