@@ -19,14 +19,14 @@
 #define REDDIT_LOGIN_H 1
 
 #include <config.h>
-#include <stdio.h>
 #include <argp.h>
-#include "reddit_priv.h"
+#include "reddit.h"
 
 struct reddit_login_options_t
 {
   char *username;
   char *password;
+  int no_wallet;
   struct reddit_state_t *state;
   int parsing_errors;
 };
