@@ -19,13 +19,14 @@
 #define REDDIT_LS_H 1
 
 #include <config.h>
-#include <stdio.h>
 #include <argp.h>
-#include "reddit_priv.h"
+#include "reddit.h"
 
 struct reddit_ls_options_t
 {
   struct reddit_state_t *state;
+  char *stories;
+  size_t stories_len;
   int parsing_errors;
 };
 
