@@ -16,73 +16,39 @@
   02110-1301, USA.
 */
 #include <config.h>
-#include <stdio.h>
 #include <stdlib.h>
-#include "next.h"
 #include "gettext-more.h"
 #include "xvasprintf.h"
+#include "reddit_priv.h"
+#include "next.h"
 
-static struct argp_option options[] = 
-{
-    {0}
-};
-
-static error_t 
-parse_opt (int key, char *arg, struct argp_state *state)
-{
-  struct reddit_next_options_t *opt = NULL;
-  if (state)
-    opt = (struct reddit_next_options_t*) state->input;
-  switch (key)
-    {
-    case ARGP_KEY_ARG:
-        {
-          if (!opt->parsing_errors)
-            {
-              argp_failure (state, 0, 0, 
-                            _("This command doesn't take an argument."));
-              opt->parsing_errors = 1;
-            }
-        }
-      break;
-    case ARGP_KEY_INIT:
-      opt->parsing_errors = 0;
-      break;
-    default:
-      return ARGP_ERR_UNKNOWN;
-    }
-  return 0;
-}
-
-struct argp reddit_next_argp = { options, parse_opt, "", N_("Go to the next page.\v") };
+struct argp reddit_next_argp = { NULL, noargs_parse_opt, "", N_("Go to the next page.\v") };
 
 int 
 reddit_next_parse_argp (struct reddit_state_t *state, int argc, char **argv, struct argp *argp)
 {
   int err = 0;
-  struct reddit_next_options_t return_options;
-  return_options.state = state;
-
-  err = argp_parse (argp, argc, argv, ARGP_NO_EXIT,  0, &return_options);
-  if (!err && !return_options.parsing_errors && ! argp_help_check (argc, argv))
-    return reddit_next (state, &return_options);
+  int parsing_errors;
+  err = argp_parse (argp, argc, argv, ARGP_NO_EXIT,  0, &parsing_errors);
+  if (!err && !parsing_errors && ! argp_help_check (argc, argv))
+    return reddit_next (state);
   else
     return 0;
 }
 
 int 
-reddit_next(struct reddit_state_t *state, struct reddit_next_options_t *options)
+reddit_next(struct reddit_state_t *state)
 {
   int response = 0;
   int err = 0;
-  char *page = xasprintf ("?count=%d&after=%s", 
+  char *page = xasprintf ("count=%d&after=%s", 
                           state->stories[state->num_stories-1].story_number,
                            state->stories[state->num_stories-1].id);
   err = reddit_load_and_show_stories (state, page, -1, NULL, &response);
   if (err)
     {
-      fprintf (state->out, _("Error: Couldn't get the next page.  "
-                             "(HTTP /1.1 %d err=%d)\n"), response, err);
+      reddintf (state, _("Error: Couldn't get the next page.  "
+                         "(HTTP /1.1 %d err=%d)\n"), response, err);
       err = 0;
     }
   free (page);
