@@ -16,15 +16,18 @@
   02110-1301, USA.
 */
 #include <config.h>
+#include <stdio.h>
 #include <stdlib.h>
 #include <error.h>
 #include <string.h>
 #include <argp.h>
 #include <argz.h>
 #include <unistd.h>
-#include "opts.h"
+#include "xvasprintf.h"
 #include "gettext-more.h"
+#include "opts.h"
 #include "reddit_priv.h"
+#include "wallet.h"
 
 #define FULL_VERSION PACKAGE_NAME " " PACKAGE_VERSION
 
@@ -37,18 +40,43 @@ const char *argp_program_bug_address = "<" PACKAGE_BUGREPORT ">";
 struct arguments_t arguments;
 static struct argp_option options[] = 
 {
-    { "quiet", OPT_QUIET, NULL, 0, N_("don't show the initial banner"), 0 },
-    { "login", OPT_LOGIN, "USER", 0, N_("login as USER to " REDDIT_SITE ), 0 },
+    { "quiet", OPT_QUIET, NULL, 0, N_("don't show the initial banner") },
+    { "login", OPT_LOGIN, "USER", 0, N_("login as USER to reddit" ) },
+    { "host", OPT_HOST, "NAME", 0, 
+      N_("connect to NAME instead of " REDDIT_SITE) },
+    { "proxy", OPT_PROXY, "HOST:PORT", 0, N_("use a proxy to access reddit") },
+    { "wallet", OPT_PASSWORD_WALLET, "FILE", OPTION_ARG_OPTIONAL, 
+      N_("store/retrieve a password in an encrypted FILE ") },
     { 0 }
 };
 
+static char*
+get_default_wallet_filename()
+{
+  return xasprintf("%s/.%s-wallet", getenv("HOME"), PACKAGE);
+}
+
 static void
 init_options (struct reddit_options_t *app)
 {
   app->quiet = -1;
+  char *wallet = getenv("REDDIT_WALLET");
+  if (wallet && atoi (wallet))
+    app->wallet = get_default_wallet_filename();
   return;
 }
 
+static char *
+argp_parse_proxy (struct argp_state *state, char *p, struct reddit_state_t *r)
+{
+  if (g_regex_match_simple ("[\\w\\-_]+(\\.[\\w\\-_]+)+([\\w\\-\\.,@"
+                            "?^=%&amp;:/~\\+#]*[\\w\\-\\@?^=%&amp;/~\\+#])?",
+                            p, G_REGEX_CASELESS, 0))
+    return p;
+  argp_failure (state, 0, 0, _("The proxy `%s' is malformed."), p);
+  return NULL;
+}
+
 static error_t 
 parse_opt (int key, char *arg, struct argp_state *state) 
 {
@@ -56,6 +84,38 @@ parse_opt (int key, char *arg, struct argp_state *state)
 
   switch (key) 
     {
+    case OPT_HOST:
+      arguments->reddit.host = arg;
+      break;
+    case OPT_PASSWORD_WALLET:
+      free (arguments->reddit.wallet);
+      if (!arg)
+        arguments->reddit.wallet = get_default_wallet_filename ();
+      else
+        arguments->reddit.wallet = strdup (arg);
+      if (access (arguments->reddit.wallet, W_OK) != 0)
+        {
+          free (arguments->reddit.wallet);
+          arguments->reddit.wallet = NULL;
+        }
+      break;
+    case OPT_PROXY:
+      if (argp_parse_proxy (state, arg, NULL))
+        {
+          arguments->reddit.proxy = arg;
+          char *colon = strrchr (arg, ':');
+          if (colon)
+            {
+              char *end = NULL;
+              *colon = '\0';
+              unsigned long val = strtoul (++colon, &end, 10);
+              if ((int)val > 0)
+                arguments->reddit.proxy_port = val;
+            }
+          else
+            arguments->reddit.proxy_port = DEFAULT_PROXY_PORT;
+        }
+      break;
     case OPT_QUIET:
 	arguments->reddit.quiet = 1;
       break;
@@ -81,14 +141,10 @@ parse_opt (int key, char *arg, struct argp_state *state)
   return 0;
 }
 
-
-static const struct argp_child child_parsers[] = 
-{
-    {0}
-};
-
 struct argp argp = { options, parse_opt, "[SUBREDDIT]", 
-  N_("A bandwidth-saving client for reddit.com."), child_parsers, 0, PACKAGE }; 
+  N_("A bandwidth-saving client for reddit.com.\v"
+     "The default password wallet file is `~/.reddit-wallet'."), 0, 0, 
+  PACKAGE }; 
 
 static void 
 set_default_options (struct reddit_options_t *app)
