@@ -22,8 +22,11 @@
 // the options
 enum app_command_line_options_t
 {
+  OPT_PROXY = -211,
+  OPT_HOST = 'h',
   OPT_LOGIN = 'l',
   OPT_QUIET = 'q',
+  OPT_PASSWORD_WALLET = 'w',
 };
 
 struct arguments_t 
@@ -35,5 +38,6 @@ struct arguments_t
 void parse_opts (int argc, char **argv, struct arguments_t *arguments);
 
 #define DEFAULT_QUIET_VALUE "0"
+#define DEFAULT_PROXY_PORT 8080
 
 #endif
