@@ -52,6 +52,7 @@
 #include "submit.h"
 #include "save.h"
 #include "unsave.h"
+#include "whoami.h"
 
 #define REDDIT_PROMPT           "reddit> "
 
@@ -75,6 +76,9 @@ enum
   GOSUB, 
   GOBACK, 
   LS,
+  PWD,
+  WHOAMI,
+  PAGESIZE,
   RELOAD,
   HELP,
   WARRANTY,
@@ -101,6 +105,9 @@ static char *const cmds[] =
   [GOSUB] = N_("gosub"),
   [GOBACK] = N_("return"),
   [LS] = N_("ls"),
+  [PWD] = N_("pwd"),
+  [WHOAMI] = N_("whoami"),
+  [PAGESIZE] = N_("pagesize"),
   [RELOAD] = N_("reload"),
   [HELP] = N_("help"),
   [WARRANTY] = N_("warranty"),
@@ -127,6 +134,9 @@ static  struct argp * const parsers[] =
   [GOSUB] = &reddit_gosub_argp,
   [GOBACK] = &reddit_return_argp,
   [LS] = &reddit_ls_argp,
+  [PWD] = NULL,
+  [WHOAMI] = &reddit_whoami_argp,
+  [PAGESIZE] = NULL,
   [RELOAD] = &reddit_reload_argp,
   [HELP] = NULL,
   [WARRANTY] = NULL,
@@ -354,12 +364,35 @@ reddit_parse_command (struct reddit_state_t *state, char *line, int *quit)
       else
         reddit_unknown_command (state);
       break;
+    case WHOAMI:
+      if (!value && argp)
+        err = reddit_whoami_parse_argp (state, argc, argv, argp);
+      else
+        reddit_unknown_command (state);
+      break;
     case RELOAD:
       if (!value && argp)
         err = reddit_reload_parse_argp (state, argc, argv, argp);
       else
         reddit_unknown_command (state);
       break;
+    case PAGESIZE:
+      if (!value)
+        err = reddit_page_size (state);
+      else
+        err = reddit_set_page_size (state, value);
+      break;
+    case PWD:
+      if (!value)
+        {
+          if (state->subreddit == NULL)
+            reddintf (state, "all\n");
+          else
+            reddintf (state, "%s\n", state->subreddit);
+        }
+      else
+        reddit_unknown_command (state);
+      break;
     case QUIT:
       if (!value)
         {
@@ -371,17 +404,37 @@ reddit_parse_command (struct reddit_state_t *state, char *line, int *quit)
       break;
     default:
         {
-          char *end = NULL;
-          int low, high;
-          reddit_get_story_id_range (state, &low, &high);
-          unsigned long int val = strtoul (line, &end, 0);
-          if (end == NULL || end == line || (int)val < low || (int) val > high)
-            reddit_unknown_command (state);
-          else
+          char *prev = NULL;
+          char *reddit;
+          int found = 0;
+          while ((reddit = 
+                  argz_next (state->reddits, state->reddits_len, prev)))
             {
-              struct reddit_view_options_t view_options;
-              view_options.story_id = (int) val;
-              reddit_view (state, &view_options);
+              prev = reddit;
+              if (strcasecmp (reddit, line) == 0)
+                {
+                  found = 1;
+                  struct reddit_gosub_options_t gosub_options;
+                  gosub_options.subreddit = reddit;
+                  reddit_gosub (state, &gosub_options);
+                }
+            }
+
+          if (found == 0)
+            {
+              char *end = NULL;
+              int low, high;
+              reddit_get_story_id_range (state, &low, &high);
+              unsigned long int val = strtoul (line, &end, 0);
+              if (end == NULL || end == line || 
+                  (int)val < low || (int) val > high)
+                reddit_unknown_command (state);
+              else
+                {
+                  struct reddit_view_options_t view_options;
+                  view_options.story_id = (int) val;
+                  reddit_view (state, &view_options);
+                }
             }
         }
       break;
@@ -455,6 +508,27 @@ reddit_interactive (struct reddit_state_t *state, struct reddit_options_t *argum
   return err;
 }
 
+static void
+add_default_subreddits (struct reddit_state_t *state)
+{
+  argz_add (&state->reddits, &state->reddits_len, "pics");
+  argz_add (&state->reddits, &state->reddits_len, "reddit.com");
+  argz_add (&state->reddits, &state->reddits_len, "funny");
+  argz_add (&state->reddits, &state->reddits_len, "politics");
+  argz_add (&state->reddits, &state->reddits_len, "AskReddit");
+  argz_add (&state->reddits, &state->reddits_len, "WTF");
+  argz_add (&state->reddits, &state->reddits_len, "gaming");
+  argz_add (&state->reddits, &state->reddits_len, "science");
+  argz_add (&state->reddits, &state->reddits_len, "worldnews");
+  argz_add (&state->reddits, &state->reddits_len, "programming");
+  argz_add (&state->reddits, &state->reddits_len, "atheism");
+  argz_add (&state->reddits, &state->reddits_len, "technology");
+  argz_add (&state->reddits, &state->reddits_len, "IAmA");
+  argz_add (&state->reddits, &state->reddits_len, "comics");
+  argz_add (&state->reddits, &state->reddits_len, "videos");
+  argz_add (&state->reddits, &state->reddits_len, "todayilearned");
+}
+
 int 
 reddit (struct reddit_options_t *arguments)
 {
@@ -463,19 +537,38 @@ reddit (struct reddit_options_t *arguments)
 
   remove (REDDIT_COOKIEJAR);
   memset (&state, 0, sizeof (state));
+  state.wallet = arguments->wallet;
   state.links_binary = g_find_program_in_path ("links");
   if (state.links_binary == NULL)
     {
       fprintf (stderr, _("Error: Couldn't find the `links' program in your "
-                         "path.  It is a required to run this software.\n"));
+                         "path.  It is required to run this software.\n"));
+      return 0;
+    }
+  state.openssl_binary = g_find_program_in_path ("openssl");
+  if (state.openssl_binary == NULL)
+    {
+      fprintf (stderr, _("Error: Couldn't find the `openssl' program in your "
+                         "path.  It is required to run this software.\n"));
       return 0;
     }
   state.browser_binary = strdup (state.links_binary);
+  if (arguments->host == NULL)
+    state.site = strdup (REDDIT_SITE);
+  else
+    state.site = strdup (arguments->host);
 
+  state.page_size = 2;
+  add_default_subreddits (&state);
   curl_global_init (CURL_GLOBAL_ALL);
   state.curl = curl_easy_init();
   curl_easy_setopt (state.curl, CURLOPT_COOKIEFILE, REDDIT_COOKIEJAR);
   curl_easy_setopt (state.curl, CURLOPT_COOKIEJAR, REDDIT_COOKIEJAR);
+  if (arguments->proxy)
+    {
+      curl_easy_setopt (state.curl, CURLOPT_PROXY, arguments->proxy);
+      curl_easy_setopt (state.curl, CURLOPT_PROXYPORT, arguments->proxy_port);
+    }
 
   state.out = stdout;
 
@@ -507,5 +600,9 @@ reddit (struct reddit_options_t *arguments)
   free (state.links_binary);
   free (state.browser_binary);
   free (state.browser_options);
+  free (state.openssl_binary);
+  free (state.reddits);
+  free (state.site);
+  free (arguments->wallet);
   return err;
 }
