@@ -18,29 +18,10 @@
 #ifndef REDDIT_PRIV_H
 #define REDDIT_PRIV_H 1
 
-#include <curl/curl.h>
-#include <glib.h>
+#include <argp.h>
 #include "story.h"
 
-struct reddit_state_t
-{
-  int logged_in;
-  char *username;
-  CURL *curl;
-  FILE *out;
-  struct reddit_story_t *stories;
-  int num_stories;
-  char *command; //current command we're working on.
-  int story_number; //current story number we're looking at.
-  int whats; //what tab we're on.
-  char *subreddit; //what subreddit we're in.
-  gchar *browser_binary; //where the browser program is living 
-  gchar *browser_options; //what options to give to the browser program
-  gchar *links_binary; //where the links program is living (for html2text)
-  char *modhash; //the last modhash we saw.
-  char *page; //what page we're on.
-  int columns; //how many columns are on our screen.
-};
+#include "reddit.h"
 
 int reddit_load_and_show_stories (struct reddit_state_t *state, char *page, int whats, char *subreddit, int *response);
 void reddit_reshow_stories (struct reddit_state_t *state);
@@ -49,16 +30,12 @@ int argp_help_check (int argc, char **argv);
 int reddit_update_modhash (struct reddit_state_t *state);
 void reddit_line (struct reddit_state_t *state);
 void reddit_banner (struct reddit_state_t *state, char *title);
-int reddit_history(struct reddit_state_t *state);
-int reddit_warranty (struct reddit_state_t *state);
-int reddit_browser (struct reddit_state_t *state);
-int reddit_set_browser (struct reddit_state_t *state, char *value);
-int reddit_browser_options (struct reddit_state_t *state);
-int reddit_set_browser_options (struct reddit_state_t *state, char *value);
 void reddit_unknown_command (struct reddit_state_t *state);
-int reddit_set_history (struct reddit_state_t *state, char *value);
 int reddit_post (struct reddit_state_t *state, char *action, char *post, int *resp, char **msg);
+int reddintf (struct reddit_state_t *state, char *fmt, ...);
+error_t noargs_parse_opt (int key, char *arg, struct argp_state *state);
 
 #define REDDIT_SITE             "www.reddit.com" //no prefix, no slashes.
 #define REDDIT_COOKIEJAR        "/tmp/" PACKAGE ".crumbs"
+#define REDDIT_WALLET_PASS      "thisisinsecurebutbetterthanplaintext"
 #endif
