@@ -16,44 +16,12 @@
   02110-1301, USA.
 */
 #include <config.h>
-#include <stdio.h>
 #include <stdlib.h>
-#include "reload.h"
 #include "gettext-more.h"
+#include "reddit_priv.h"
+#include "reload.h"
 
-static struct argp_option options[] = 
-{
-    {0}
-};
-
-static error_t 
-parse_opt (int key, char *arg, struct argp_state *state)
-{
-  struct reddit_reload_options_t *opt = NULL;
-  if (state)
-    opt = (struct reddit_reload_options_t*) state->input;
-  switch (key)
-    {
-    case ARGP_KEY_ARG:
-        {
-          if (!opt->parsing_errors)
-            {
-              argp_failure (state, 0, 0, 
-                            _("This command doesn't take an argument."));
-              opt->parsing_errors = 1;
-            }
-        }
-      break;
-    case ARGP_KEY_INIT:
-      opt->parsing_errors = 0;
-      break;
-    default:
-      return ARGP_ERR_UNKNOWN;
-    }
-  return 0;
-}
-
-struct argp reddit_reload_argp = { options, parse_opt, "", 
+struct argp reddit_reload_argp = { NULL, noargs_parse_opt, "", 
   N_("Re-download the list of the stories and display them.\v"
      "Save bandwidth by using the `ls' command.") };
 
@@ -61,27 +29,26 @@ int
 reddit_reload_parse_argp (struct reddit_state_t *state, int argc, char **argv, struct argp *argp)
 {
   int err = 0;
-  struct reddit_reload_options_t reload_options;
-  reload_options.state = state;
+  int parsing_errors;
 
-  err = argp_parse (argp, argc, argv, ARGP_NO_EXIT, 0, &reload_options);
+  err = argp_parse (argp, argc, argv, ARGP_NO_EXIT, 0, &parsing_errors);
 
-  if (!err && !reload_options.parsing_errors && !argp_help_check (argc, argv))
-    return reddit_reload (state, &reload_options);
+  if (!err && !parsing_errors && !argp_help_check (argc, argv))
+    return reddit_reload (state);
   else
     return 0;
 }
 
 int 
-reddit_reload (struct reddit_state_t *state, struct reddit_reload_options_t *options)
+reddit_reload (struct reddit_state_t *state)
 {
   int err = 0;
   int response = 0;
   err = reddit_load_and_show_stories (state, NULL, -1, NULL, &response);
   if (err)
     {
-      fprintf (state->out, _("Error: Couldn't reload the page.  "
-                             "(HTTP /1.1 %d err=%d)\n"), response, err);
+      reddintf (state, _("Error: Couldn't reload the page.  "
+                         "(HTTP /1.1 %d err=%d)\n"), response, err);
       err = 0;
     }
   return err;
