@@ -19,17 +19,10 @@
 #define REDDIT_RELOAD_H 1
 
 #include <config.h>
-#include <stdio.h>
 #include <argp.h>
-#include "reddit_priv.h"
-
-struct reddit_reload_options_t
-{
-  struct reddit_state_t *state;
-  int parsing_errors;
-};
+#include "reddit.h"
 
 int reddit_reload_parse_argp (struct reddit_state_t *, int argc, char **argv, struct argp *);
-int reddit_reload (struct reddit_state_t *, struct reddit_reload_options_t *);
+int reddit_reload (struct reddit_state_t *);
 extern struct argp reddit_reload_argp;
 #endif
