@@ -16,20 +16,20 @@
   02110-1301, USA.
 */
 #include <config.h>
-#include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
 #ifdef HAVE_LIBREADLINE
+#include <stdio.h>
 #include <readline/readline.h>
 #include <readline/history.h>
 #endif
 #include <glib.h>
 #include "xvasprintf.h"
+#include "reddit_priv.h"
 #include "share.h"
 #include "story.h"
 #include "stories.h"
 #include "gettext-more.h"
-#include "read-file.h"
 
 static struct argp_option options[] = 
 {
@@ -176,14 +176,14 @@ reddit_share (struct reddit_state_t *state, struct reddit_share_options_t *optio
   int err = 0;
   if (state->logged_in == 0)
     {
-      fprintf (state->out, _("You need to login to share a story."
-                             "  Login using the `login' command.\n"));
+      reddintf (state, _("You need to login to share a story."
+                         "  Login using the `login' command.\n"));
       return 0;
     }
   int malloced_message = 0;
   if (options->add_message && options->message == NULL)
     {
-      fprintf (state->out, _("Type in your message and then press enter.\n"));
+      reddintf (state, _("Type in your message and then press enter.\n"));
 #ifdef HAVE_LIBREADLINE
       stifle_history (0);
       options->message = readline (_("Message: "));
@@ -198,7 +198,7 @@ reddit_share (struct reddit_state_t *state, struct reddit_share_options_t *optio
     {
       options->message = 
         xasprintf ("%s from http://%s/ has shared a link with you.",
-                   state->username, REDDIT_SITE);
+                   state->username, state->site);
       malloced_message = 1;
     }
 
@@ -212,16 +212,16 @@ reddit_share (struct reddit_state_t *state, struct reddit_share_options_t *optio
   if (!err)
     reddit_update_modhash (state);
   if (!err)
-    fprintf (state->out, _("The story has been shared.\n"));
+    reddintf (state, _("The story has been shared.\n"));
   else
     {
-      fprintf (state->out, _("Error: Couldn't share the story.  "
-                             "(HTTP /1.1 %d err=%d)\n"), response, err);
+      reddintf (state, _("Error: Couldn't share the story.  "
+                         "(HTTP /1.1 %d err=%d)\n"), response, err);
       if (errmsg)
         {
-          fprintf (state->out, _("Maybe this gobbledegook will be useful "
-                                 "in diagnosing what went wrong:\n"
-                                 "%s\n"), errmsg);
+          reddintf (state, _("Maybe this gobbledegook will be useful "
+                             "in diagnosing what went wrong:\n"
+                             "%s\n"), errmsg);
           free (errmsg);
         }
     }
