@@ -21,6 +21,7 @@
 #include <argp.h>
 #include <glib.h>
 #include <unistd.h>
+#include <argz.h>
 #include "stories.h"
 #include "reddit_priv.h"
 #include "gettext-more.h"
@@ -56,6 +57,45 @@ reddit_get_modhash_from_chunk (struct reddit_state_t *state, char *data)
   return;
 }
 
+static int
+reddit_get_reddits_from_chunk (struct reddit_state_t *state, char *data)
+{
+  int first = 1;
+  int err = 0;
+  gchar **fields = g_regex_split_simple ("<div class=\"drop-choices srdrop \"",
+                                         data, 0, 0);
+  int num_fields = g_strv_length (fields);
+  if (num_fields > 1)
+    {
+      g_strfreev (fields);
+      fields = g_regex_split_simple ("/r/", data, 0, 0);
+      num_fields = g_strv_length (fields);
+      if (num_fields > 1)
+        {
+          int i = 1;
+          for (; i < num_fields; i++)
+            {
+              char *endslash = strchr (fields[i], '/');
+              if (endslash)
+                {
+                  if (first)
+                    {
+                      free (state->reddits);
+                      state->reddits = NULL;
+                      state->reddits_len = 0;
+                      first = 0;
+                    }
+                  *endslash = '\0';
+                  argz_add (&state->reddits, &state->reddits_len, 
+                            fields[i]);
+                }
+            }
+        }
+    }
+  g_strfreev (fields);
+  return err;
+}
+
 static int
 reddit_load_stories_from_data (struct reddit_state_t *state, char *data, size_t data_len, struct reddit_story_t **stories)
 {
@@ -65,7 +105,10 @@ reddit_load_stories_from_data (struct reddit_state_t *state, char *data, size_t
     {
       *stories = malloc (sizeof (struct reddit_story_t ) * (num_stories - 1));
       if (state->logged_in)
-        reddit_get_modhash_from_chunk (state, fields[0]);
+        {
+          reddit_get_modhash_from_chunk (state, fields[0]);
+          reddit_get_reddits_from_chunk (state, fields[0]);
+        }
       if (*stories)
         {
           gchar **ptr = &fields[1];
