@@ -671,9 +671,9 @@ reddit_show_story (struct reddit_state_t *state, struct reddit_story_t *story)
   if (state->whats != REDDIT_WHATS_NEW)
     {
       if (story->num_comments == 1)
-        fprintf (state->out, "* %d comment", story->num_comments);
+        fprintf (state->out, _("* %d comment"), story->num_comments);
       else if (story->num_comments >= 0)
-        fprintf (state->out, "* %d comments", story->num_comments);
+        fprintf (state->out, _("* %d comments"), story->num_comments);
     }
   fprintf (state->out, "\n\n\n");
 }
