@@ -16,15 +16,16 @@
   02110-1301, USA.
 */
 #include <config.h>
-#include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <glib.h>
 #include "xvasprintf.h"
 #ifdef HAVE_LIBREADLINE
+#include <stdio.h>
 #include <readline/readline.h>
 #include <readline/history.h>
 #endif
+#include "reddit_priv.h"
 #include "submit.h"
 #include "stories.h"
 #include "gettext-more.h"
@@ -149,7 +150,8 @@ reddit_submit_story (struct reddit_state_t *state, struct reddit_submit_options_
   char *msg = NULL;
   err = reddit_post (state, "submit", post, resp, &msg);
   free (post);
-  if (strstr (msg, "http://" REDDIT_SITE "/") == NULL)
+  char *match = xasprintf ("http://%s/", state->site);
+  if (strstr (msg, match) == NULL)
     {
       if (!err)
         err = -1;
@@ -157,6 +159,7 @@ reddit_submit_story (struct reddit_state_t *state, struct reddit_submit_options_
     }
   else
     free (msg);
+  free (match);
   return err;
 }
 
@@ -166,15 +169,15 @@ reddit_submit (struct reddit_state_t *state, struct reddit_submit_options_t *opt
   int err = 0;
   if (state->logged_in == 0)
     {
-      fprintf (state->out, _("You need to login to submit a story."
-                             "  Login using the `login' command.\n"));
+      reddintf (state, _("You need to login to submit a story."
+                         "  Login using the `login' command.\n"));
       return 0;
     }
   int malloced_title = 0;
   if (options->title == NULL)
     {
       //go get a title.
-      fprintf (state->out, _("Type in your title and then press enter.\n"));
+      reddintf (state, _("Type in your title and then press enter.\n"));
 #ifdef HAVE_LIBREADLINE
       stifle_history (0);
       options->title = readline (_("Title: "));
@@ -192,16 +195,16 @@ reddit_submit (struct reddit_state_t *state, struct reddit_submit_options_t *opt
   if (!err)
     reddit_update_modhash (state);
   if (!err)
-    fprintf (state->out, _("The story has been submitted.\n"));
+    reddintf (state, _("The story has been submitted.\n"));
   else
     {
-      fprintf (state->out, _("Error: Couldn't submit the story.  "
-                             "(HTTP /1.1 %d err=%d)\n"), response, err);
+      reddintf (state, _("Error: Couldn't submit the story.  "
+                         "(HTTP /1.1 %d err=%d)\n"), response, err);
       if (errmsg)
         {
-          fprintf (state->out, _("Maybe this gobbledegook will be useful "
-                                 "in diagnosing what went wrong:\n"
-                                 "%s\n"), errmsg);
+          reddintf (state, _("Maybe this gobbledegook will be useful "
+                             "in diagnosing what went wrong:\n"
+                             "%s\n"), errmsg);
           free (errmsg);
         }
     }
