@@ -16,20 +16,14 @@
   02110-1301, USA.
 */
 #include <config.h>
-#include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include "xvasprintf.h"
+#include "reddit_priv.h"
 #include "upvote.h"
 #include "story.h"
 #include "stories.h"
 #include "gettext-more.h"
-#include "read-file.h"
-
-static struct argp_option options[] = 
-{
-    {0}
-};
 
 static error_t 
 parse_opt (int key, char *arg, struct argp_state *state)
@@ -81,7 +75,7 @@ help_filter (int key, const char *text, void *input)
   return argp_parse_story_help_filter (key, text, o ? o->state : NULL);
 }
 
-struct argp reddit_upvote_argp = { options, parse_opt, "STORY-NUMBER",N_("Increases the number of people who liked a given story.  Tallies your vote in favour of a story.\v"), 0, help_filter};
+struct argp reddit_upvote_argp = { NULL, parse_opt, "STORY-NUMBER",N_("Increases the number of people who liked a given story.  Tallies your vote in favour of a story.\v"), 0, help_filter};
 
 int 
 reddit_upvote_parse_argp (struct reddit_state_t *state, int argc, char **argv, struct argp *argp)
@@ -133,7 +127,7 @@ reddit_upvote (struct reddit_state_t *state, struct reddit_upvote_options_t *opt
   int err = 0;
   if (state->logged_in == 0)
     {
-      fprintf (state->out, _("You need to login to vote on a story."
+      reddintf (state, _("You need to login to vote on a story."
                              "  Login using the `login' command.\n"));
       return 0;
     }
@@ -147,16 +141,16 @@ reddit_upvote (struct reddit_state_t *state, struct reddit_upvote_options_t *opt
   if (!err)
     reddit_update_modhash (state);
   if (!err)
-    fprintf (state->out, _("The story has been upvoted.\n"));
+    reddintf (state, _("The story has been upvoted.\n"));
   else
     {
-      fprintf (state->out, _("Error: Couldn't upvote the story "
-                             "HTTP /1.1 %d err=%d)\n"), response, err);
+      reddintf (state, _("Error: Couldn't upvote the story "
+                         "HTTP /1.1 %d err=%d)\n"), response, err);
       if (errmsg)
         {
-          fprintf (state->out, _("Maybe this gobbledegook will be useful "
-                                 "in diagnosing what went wrong:\n"
-                                 "%s\n"), errmsg);
+          reddintf (state, _("Maybe this gobbledegook will be useful "
+                             "in diagnosing what went wrong:\n"
+                             "%s\n"), errmsg);
           free (errmsg);
         }
     }
