@@ -16,22 +16,16 @@
   02110-1301, USA.
 */
 #include <config.h>
-#include <stdio.h>
 #include <stdlib.h>
 #include <glib.h>
 #include <argz.h>
-#include "xvasprintf.h"
+#include "reddit_priv.h"
 #include "view.h"
 #include "story.h"
 #include "stories.h"
 #include "gettext-more.h"
 #include "wait-process.h"
 
-static struct argp_option options[] = 
-{
-    {0}
-};
-
 static error_t 
 parse_opt (int key, char *arg, struct argp_state *state)
 {
@@ -82,7 +76,7 @@ help_filter (int key, const char *text, void *input)
   return argp_parse_story_help_filter (key, text, o ? o->state : NULL);
 }
 
-struct argp reddit_view_argp = { options, parse_opt, "STORY-NUMBER",N_("Increases the number of people who liked a given story.  Tallies your vote in favour of a story.\v"), 0, help_filter };
+struct argp reddit_view_argp = { NULL, parse_opt, "STORY-NUMBER",N_("Increases the number of people who liked a given story.  Tallies your vote in favour of a story.\v"), 0, help_filter };
 
 int 
 reddit_view_parse_argp (struct reddit_state_t *state, int argc, char **argv, struct argp *argp)
@@ -144,9 +138,8 @@ reddit_view (struct reddit_state_t *state, struct reddit_view_options_t *options
       if (err)
         {
           err = 0;
-          fprintf (state->out, 
-                   _("Error: Sorry, something went wrong "
-                     "when viewing the story.\n"));
+          reddintf (state, _("Error: Sorry, something went wrong "
+                             "when viewing the story.\n"));
         }
     }
   return err;
