@@ -16,12 +16,11 @@
   02110-1301, USA.
 */
 #include <config.h>
-#include <stdio.h>
 #include <stdlib.h>
-#include "xvasprintf.h"
+#include <argz.h>
+#include "reddit_priv.h"
 #include "whats.h"
 #include "gettext-more.h"
-#include <argz.h>
 
 char *const whats[] = 
 {
@@ -39,11 +38,6 @@ reddit_whats_to_string (int w)
   return whats[w];
 }
 
-static struct argp_option options[] = 
-{
-    {0}
-};
-
 static char *generate_whats_list()
 {
   char *argz = NULL;
@@ -107,7 +101,7 @@ parse_opt (int key, char *arg, struct argp_state *state)
   return 0;
 }
 
-struct argp reddit_whats_argp = { options, parse_opt, "`hot' | `new' | `controversial' | `top' | `saved'",N_("Flips the tab on the list of stories.\v")};
+struct argp reddit_whats_argp = { NULL, parse_opt, "`hot' | `new' | `controversial' | `top' | `saved'",N_("Flips the tab on the list of stories.\v")};
 
 int 
 reddit_whats_parse_argp (struct reddit_state_t *state, int argc, char **argv, struct argp *argp)
@@ -132,8 +126,8 @@ reddit_whats (struct reddit_state_t *state, struct reddit_whats_options_t *optio
     {
       if (state->logged_in == 0)
         {
-          fprintf (state->out, _("You need to login to see your saved stories."
-                                 "  Login using the `login' command.\n"));
+          reddintf (state, _("You need to login to see your saved stories."
+                             "  Login using the `login' command.\n"));
           return 0;
         }
       subreddit = "";
@@ -146,12 +140,11 @@ reddit_whats (struct reddit_state_t *state, struct reddit_whats_options_t *optio
   if (err)
     {
       if (response == 200)
-        fprintf (state->out, _("There doesn't seem to be anything here.\n"));
+        reddintf (state, _("There doesn't seem to be anything here.\n"));
       else
-        fprintf (state->out, _("Error: Couldn't load the `%s' page.  "
-                               "(HTTP /1.1 %d err=%d)\n"), 
-                 whats[options->whats],
-                 response, err);
+        reddintf (state, _("Error: Couldn't load the `%s' page.  "
+                           "(HTTP /1.1 %d err=%d)\n"), 
+                 whats[options->whats], response, err);
       err = 0;
     }
   return err;
