@@ -19,9 +19,8 @@
 #define REDDIT_WHATS_H 1
 
 #include <config.h>
-#include <stdio.h>
 #include <argp.h>
-#include "reddit_priv.h"
+#include "reddit.h"
 
 enum reddit_whats_enum_t
 {
